@@ -5,6 +5,10 @@ import traceback
 from io import StringIO
 from typing import Any, Dict
 
+from uvicorn.logging import DefaultFormatter
+
+from .main import glove
+
 try:
     import pygments
     from pygments.lexers import Python3TracebackLexer
@@ -27,6 +31,8 @@ except ImportError:  # pragma: no cover
         return pformat(extra)
 
 
+logger = logging.getLogger('foxglove.logs')
+
 # only way to get "extra" from a LogRecord is to look in record.__dict__ and ignore all the standard keys
 standard_record_keys = {
     'name',
@@ -50,33 +56,31 @@ standard_record_keys = {
     'processName',
     'process',
     'message',
+    'color_message',
 }
 
 
-class HighlightStreamHandler(logging.StreamHandler):
-    def setFormatter(self, fmt):
-        self.formatter = fmt
-        self.formatter.stream_is_tty = isatty and isatty(self.stream)
-
-
-class HighlightExtraFormatter(logging.Formatter):
-    def __init__(self, fmt=None, datefmt=None, style='%'):
-        super().__init__(fmt, datefmt, style)
-        self.stream_is_tty = False
+class HighlightExtraFormatter(DefaultFormatter):
+    def __init__(self, *args, **kwargs):
+        self.sentry_active = bool(glove.settings.sentry_dsn)
+        super().__init__(*args, **kwargs)
 
     def formatMessage(self, record):
         s = super().formatMessage(record)
-        extra = {k: v for k, v in record.__dict__.items() if k not in standard_record_keys}
-        if extra:
-            s += '\nExtra: ' + format_extra(extra, highlight=self.stream_is_tty)
+        if not self.sentry_active:
+            extra = {k: v for k, v in record.__dict__.items() if k not in standard_record_keys}
+            if extra:
+                s += '\nExtra: ' + format_extra(extra, highlight=self.should_use_colors())
         return s
 
     def formatException(self, ei):
+        if self.sentry_active:
+            return super().formatException(ei)
         sio = StringIO()
         traceback.print_exception(*ei, file=sio)
         stack = sio.getvalue()
         sio.close()
-        if self.stream_is_tty and pyg_lexer:
+        if self.should_use_colors() and pyg_lexer:
             return pygments.highlight(stack, lexer=pyg_lexer, formatter=pyg_formatter).rstrip('\n')
         else:
             return stack
@@ -94,44 +98,35 @@ def get_env_multiple(*names):
             return v
 
 
-def build_logging_config(debug: bool) -> Dict[str, Any]:
+def setup_sentry() -> None:
+    if glove.settings.sentry_dsn:
+        import sentry_sdk
+        from sentry_sdk.integrations.logging import LoggingIntegration
+
+        sentry_sdk.init(
+            dsn=glove.settings.sentry_dsn,
+            integrations=[LoggingIntegration(level=logging.INFO, event_level=logging.WARNING)],
+            release=glove.settings.release,
+            environment=glove.settings.environment,
+            server_name=get_env_multiple('DYNO', 'SERVER_NAME', 'HOSTNAME', 'HOST', 'NAME'),
+        )
+        logger.info('sentry initialised')
+    else:
+        logger.info('sentry not initialised')
+
+
+def build_logging_config() -> Dict[str, Any]:
     """
     setup logging config by updating the arq logging config
     """
-    log_level = 'DEBUG' if debug else 'INFO'
-    sentry_dsn = os.getenv('SENTRY_DSN', None)
-    if sentry_dsn in ('', '-'):
-        # thus setting an environment variable of "-" means no sentry
-        sentry_dsn = None
-
-    if sentry_dsn:
-        import sentry_sdk
-        from sentry_sdk.integrations.logging import LoggingIntegration, ignore_logger
-
-        sentry_sdk.init(
-            dsn=sentry_dsn,
-            integrations=[LoggingIntegration(level=logging.INFO, event_level=logging.WARNING)],
-            release=get_env_multiple('COMMIT', 'RELEASE'),
-            server_name=get_env_multiple('DYNO', 'SERVER_NAME', 'HOSTNAME', 'HOST', 'NAME'),
-        )
-        ignore_logger('foxglove.middleware')
-        warning_handler = {'level': 'WARNING', 'class': 'logging.NullHandler'}
-        default_filters = []
-    else:
-        warning_handler = {
-            'level': 'WARNING',
-            'class': 'foxglove.logs.HighlightStreamHandler',
-            'formatter': 'foxglove.highlighted_formatter',
-        }
-        # we don't print above warnings on foxglove.default to avoid duplicate errors in the console
-        default_filters = ['not_warnings']
-
+    settings = glove.init_settings()
+    log_level = settings.log_level
     config = {
         'version': 1,
         'disable_existing_loggers': False,
         'formatters': {
             'foxglove.default': {
-                '()': 'uvicorn.logging.DefaultFormatter',
+                '()': 'foxglove.logs.HighlightExtraFormatter',
                 'fmt': '%(levelprefix)s %(message)s',
                 'use_colors': None,
             },
@@ -139,15 +134,12 @@ def build_logging_config(debug: bool) -> Dict[str, Any]:
                 '()': 'uvicorn.logging.AccessFormatter',
                 'fmt': "%(levelprefix)s %(client_addr)s - '%(request_line)s' %(status_code)s",
             },
-            'foxglove.highlighted_formatter': {'class': 'foxglove.logs.HighlightExtraFormatter'},
         },
-        'filters': {'not_warnings': {'()': 'foxglove.logs.NotWarnings'}},
         'handlers': {
             'foxglove.default': {
                 'formatter': 'foxglove.default',
                 'class': 'logging.StreamHandler',
                 'stream': 'ext://sys.stderr',
-                'filters': default_filters,
                 'level': log_level,
             },
             'foxglove.access': {
@@ -156,17 +148,17 @@ def build_logging_config(debug: bool) -> Dict[str, Any]:
                 'stream': 'ext://sys.stdout',
                 'level': log_level,
             },
-            'foxglove.warning': warning_handler,
         },
         'loggers': {
-            '': {'handlers': ['foxglove.default', 'foxglove.warning'], 'level': log_level},
-            'uvicorn.error': {'level': 'INFO'},
+            '': {'handlers': ['foxglove.default'], 'level': log_level},
+            'uvicorn.error': {'handlers': ['foxglove.default'], 'level': log_level, 'propagate': False},
             'uvicorn.access': {'handlers': ['foxglove.access'], 'level': log_level, 'propagate': False},
         },
     }
     return config
 
 
-def setup_logging(debug: bool = False) -> None:
-    config = build_logging_config(debug)
+def setup_logging() -> None:
+    config = build_logging_config()
     logging.config.dictConfig(config)
+    setup_sentry()
